package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbPostAddress;

import java.util.List;

/**
 * 邮寄地址Service接口
 *
 * @author ruoyi
 * @date 2024-11-20
 */
public interface ITbPostAddressService
{
    /**
     * 查询邮寄地址
     *
     * @param postAddressId 邮寄地址主键
     * @return 邮寄地址
     */
    public TbPostAddress selectTbPostAddressByPostAddressId(Long postAddressId);

    /**
     * 查询邮寄地址列表
     *
     * @param tbPostAddress 邮寄地址
     * @return 邮寄地址集合
     */
    public List<TbPostAddress> selectTbPostAddressList(TbPostAddress tbPostAddress);

    /**
     * 新增邮寄地址
     *
     * @param tbPostAddress 邮寄地址
     * @return 结果
     */
    public int insertTbPostAddress(TbPostAddress tbPostAddress);

    /**
     * 修改邮寄地址
     *
     * @param tbPostAddress 邮寄地址
     * @return 结果
     */
    public int updateTbPostAddress(TbPostAddress tbPostAddress);

    /**
     * 批量删除邮寄地址
     *
     * @param postAddressIds 需要删除的邮寄地址主键集合
     * @return 结果
     */
    public int deleteTbPostAddressByPostAddressIds(Long[] postAddressIds);

    /**
     * 删除邮寄地址信息
     *
     * @param postAddressId 邮寄地址主键
     * @return 结果
     */
    public int deleteTbPostAddressByPostAddressId(Long postAddressId);

    /**
     * 查询邮寄地址
     *
     * @param memberUserId 用户ID
     * @param dataId 相关资源ID
     * @param type 类型（0-全部，1-证书）
     * @return 邮寄地址
     */
    public TbPostAddress selectTbPostAddressByMemberUserIdDataId(Long memberUserId, Long dataId, Integer type);
}
